Enum Event
#[non_exhaustive]pub enum Event {
Toplevel {
toplevel: ExtForeignToplevelHandleV1,
},
Finished,
}wayland and Linux only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Toplevel
a toplevel has been created
This event is emitted whenever a new toplevel window is created. It is emitted for all toplevels, regardless of the app that has created them.
All initial properties of the toplevel (identifier, title, app_id) will be sent immediately after this event using the corresponding events for ext_foreign_toplevel_handle_v1. The compositor will use the ext_foreign_toplevel_handle_v1.done event to indicate when all data has been sent.
Fields
toplevel: ExtForeignToplevelHandleV1Finished
the compositor has finished with the toplevel manager
This event indicates that the compositor is done sending events to this object. The client should destroy the object. See ext_foreign_toplevel_list_v1.destroy for more information.
The compositor must not send any more toplevel events after this event.
Implementations