Struct ExtForeignToplevelListV1
pub struct ExtForeignToplevelListV1 { /* private fields */ }wayland and Linux only.Expand description
list toplevels
A toplevel is defined as a surface with a role similar to xdg_toplevel. XWayland surfaces may be treated like toplevels in this protocol.
After a client binds the ext_foreign_toplevel_list_v1, each mapped toplevel window will be sent using the ext_foreign_toplevel_list_v1.toplevel event.
Clients which only care about the current state can perform a roundtrip after binding this global.
For each instance of ext_foreign_toplevel_list_v1, the compositor must create a new ext_foreign_toplevel_handle_v1 object for each mapped toplevel.
If a compositor implementation sends the ext_foreign_toplevel_list_v1.finished event after the global is bound, the compositor must not send any ext_foreign_toplevel_list_v1.toplevel events.
See also the Event enum for this interface.
Implementations
impl ExtForeignToplevelListV1
impl ExtForeignToplevelListV1
pub fn stop(&self)
pub fn stop(&self)
stop sending events
This request indicates that the client no longer wishes to receive events for new toplevels.
The Wayland protocol is asynchronous, meaning the compositor may send further toplevel events until the stop request is processed. The client should wait for a ext_foreign_toplevel_list_v1.finished event before destroying this object.
pub fn destroy(&self)
pub fn destroy(&self)
destroy the ext_foreign_toplevel_list_v1 object
This request should be called either when the client will no longer use the ext_foreign_toplevel_list_v1 or after the finished event has been received to allow destruction of the object.
If a client wishes to destroy this object it should send a ext_foreign_toplevel_list_v1.stop request and wait for a ext_foreign_toplevel_list_v1.finished event, then destroy the handles and then this object.